package com.bonus.material.warehouse.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.warehouse.domain.WhTeamReceiveDetail;
import com.bonus.material.warehouse.service.IWhTeamReceiveDetailService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 二级库接收详情Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "二级库接收详情接口")
@RestController
@RequestMapping("/wh_team_receive_detail")
public class WhTeamReceiveDetailController extends BaseController
{
    @Autowired
    private IWhTeamReceiveDetailService whTeamReceiveDetailService;

    /**
     * 查询二级库接收详情列表
     */
    @ApiOperation(value = "查询二级库接收详情列表")
    @RequiresPermissions("warehouse:detail:list")
    @GetMapping("/list")
    public TableDataInfo list(WhTeamReceiveDetail whTeamReceiveDetail)
    {
        startPage();
        List<WhTeamReceiveDetail> list = whTeamReceiveDetailService.selectWhTeamReceiveDetailList(whTeamReceiveDetail);
        return getDataTable(list);
    }

    /**
     * 导出二级库接收详情列表
     */
    @ApiOperation(value = "导出二级库接收详情列表")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:detail:export")
    @SysLog(title = "二级库接收详情", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出二级库接收详情")
    @PostMapping("/export")
    public void export(HttpServletResponse response, WhTeamReceiveDetail whTeamReceiveDetail)
    {
        List<WhTeamReceiveDetail> list = whTeamReceiveDetailService.selectWhTeamReceiveDetailList(whTeamReceiveDetail);
        ExcelUtil<WhTeamReceiveDetail> util = new ExcelUtil<WhTeamReceiveDetail>(WhTeamReceiveDetail.class);
        util.exportExcel(response, list, "二级库接收详情数据");
    }

    /**
     * 获取二级库接收详情详细信息
     */
    @ApiOperation(value = "获取二级库接收详情详细信息")
    @RequiresPermissions("warehouse:detail:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(whTeamReceiveDetailService.selectWhTeamReceiveDetailById(id));
    }

    /**
     * 新增二级库接收详情
     */
    @ApiOperation(value = "新增二级库接收详情")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:detail:add")
    @SysLog(title = "二级库接收详情", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增二级库接收详情")
    @PostMapping
    public AjaxResult add(@RequestBody WhTeamReceiveDetail whTeamReceiveDetail)
    {
        return toAjax(whTeamReceiveDetailService.insertWhTeamReceiveDetail(whTeamReceiveDetail));
    }

    /**
     * 修改二级库接收详情
     */
    @ApiOperation(value = "修改二级库接收详情")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:detail:edit")
    @SysLog(title = "二级库接收详情", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改二级库接收详情")
    @PutMapping
    public AjaxResult edit(@RequestBody WhTeamReceiveDetail whTeamReceiveDetail)
    {
        return toAjax(whTeamReceiveDetailService.updateWhTeamReceiveDetail(whTeamReceiveDetail));
    }

    /**
     * 删除二级库接收详情
     */
    @ApiOperation(value = "删除二级库接收详情")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:detail:remove")
    @SysLog(title = "二级库接收详情", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除二级库接收详情")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(whTeamReceiveDetailService.deleteWhTeamReceiveDetailByIds(ids));
    }
}
